@@ -1,4 +1,10 @@
-# Copyright IBM Corp. 2021. All Rights Reserved.
+# IBM Confidential
+# OCO Source Materials
+# 5737-B37, 5737-C49, 5737-H76
+# (C) Copyright IBM Corp. 2021, 2022  All Rights Reserved.
+# The source code for this program is not published or
+# otherwise divested of its trade secrets, irrespective of
+# what has been deposited with the U.S. Copyright Office.
 
 import base64
 import io
@@ -203,12 +209,23 @@ class WSPipelines(BaseService):
             warnings.warn("'url' doesn't start with https")
 
         url_to_iam_url = {
-            "https://api.dataplatform.dev.cloud.ibm.com": "https://iam.test.cloud.ibm.com/identity/token",
-            "https://api.dataplatform.test.cloud.ibm.com": "https://iam.cloud.ibm.com/identity/token",
-            "https://api.dataplatform.cloud.ibm.com": "https://iam.cloud.ibm.com/identity/token"
+            "dev.cloud.ibm.com":  "https://iam.test.cloud.ibm.com/identity/token",
+            "test.cloud.ibm.com": "https://iam.cloud.ibm.com/identity/token",
+            "cloud.ibm.com":      "https://iam.cloud.ibm.com/identity/token",
         }
         is_public = True
-        iam_url = url_to_iam_url.get(url)
+        iam_url = None
+
+        # ignore api. and optionally the region-specific prefix, start with `dataplatform`
+        # for instance:
+        #   https://api.dataplatform.cloud.ibm.com
+        #   https://api.eu-de.dataplatform.cloud.ibm.com
+        # both have root_url=cloud.ibm.com
+        root_idx = url.find('dataplatform')
+        if root_idx != -1:
+            root_url = url[root_idx+len('dataplatform')+1 :]
+            iam_url = url_to_iam_url.get(root_url)
+
         if iam_url is None:
             # assume it's CPD
             is_public = False
@@ -541,6 +558,12 @@ class WSPipelines(BaseService):
 
         response = None
         for output_name, output_value in outputs.items():
+            if output_name not in output_artifacts:
+                print(
+                    f'Variable {output_name} is not on the list of output variables defined by pipeline component, '
+                    f'check your pipeline definition for possible typos and omissions')
+                continue
+
             result_key = output_artifacts[output_name]
             response = storage_client.store_result(output_name, result_key, output_value)
         return response
@@ -826,4 +849,4 @@ class CamsClient(StorageClient):
         req = self.cpd_orchestration.prepare_request('PUT', uri, headers=headers, params=params, files=files)
         req = cast(requests.Request, req)
         res = self.cpd_orchestration.send(req)
-        return res
\ No newline at end of file
+        return res
