@@ -1,4 +1,11 @@
-# Copyright IBM Corp. 2021. All Rights Reserved.
+# IBM Confidential
+# OCO Source Materials
+# 5737-B37, 5737-C49, 5737-H76
+# (C) Copyright IBM Corp. 2021, 2022  All Rights Reserved.
+# The source code for this program is not published or
+# otherwise divested of its trade secrets, irrespective of
+# what has been deposited with the U.S. Copyright Office.
+
 import itertools
 import re
 from enum import Enum
@@ -203,9 +210,9 @@ class File:
 
 @attr.attrs(auto_attribs=True, frozen=True, kw_only=True)
 class Path:
-    scope: Optional[Segment[ScopeType]] = None
-    resource: Optional[Segment[Union[ResourceType, SpecialAssetsType]]] = None
-    file: Optional[File] = None
+    scope: Optional[Segment[ScopeType]]
+    resource: Optional[Segment[Union[ResourceType, SpecialAssetsType]]]
+    file: Optional[File]
 
     def __str__(self) -> str:
         result = ""
@@ -356,10 +363,10 @@ class Path:
 
 @attr.attrs(auto_attribs=True, frozen=True, kw_only=True)
 class CpdPathData:
-    has_prefix: bool = True
-    ctx: Optional[str] = None
+    has_prefix: bool
+    ctx: Optional[str]
     path: Path
-    query: Optional[Query] = None
+    query: Optional[Query]
 
     @classmethod
     def from_string(cls: Type[Self], path: str) -> Self:
@@ -570,30 +577,6 @@ class CpdPathImpl(CpdPath):
         return result
 
 class CpdScope(CpdPathImpl):
-    @classmethod
-    def project(cls: Type[Self], scope_id: str) -> Self:
-        data = CpdPathData(
-            path=Path(
-                scope=Segment(
-                    type=ScopeType.PROJECTS,
-                    id=scope_id,
-                )
-            )
-        )
-        return cls(data=data)
-
-    @classmethod
-    def space(cls: Type[Self], scope_id: str) -> Self:
-        data = CpdPathData(
-            path=Path(
-                scope=Segment(
-                    type=ScopeType.SPACES,
-                    id=scope_id,
-                )
-            )
-        )
-        return cls(data=data)
-
     # always present
     def scope_type(self) -> str:
         return self.data.path.scope.type.value
@@ -818,4 +801,4 @@ class CpdConnectionFile(CpdPathImpl):
         if len(parts) < 1:
             return "/"
         else:
-            return "/" + "/".join(parts[1:])
\ No newline at end of file
+            return "/" + "/".join(parts[1:])
